jacinle.cli.argument
====================

.. automodule:: jacinle.cli.argument

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AsEnumAction
      JacArgumentParser
      SetDeviceAction
   
   

   
   
   

   
   
   








.. rubric:: Class AsEnumAction
.. autoclass:: AsEnumAction
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class JacArgumentParser
.. autoclass:: JacArgumentParser
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SetDeviceAction
.. autoclass:: SetDeviceAction
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







